@@ -3,53 +3,76 @@
 ###################################################
 ### code chunk number 1: NMOFex.Rnw:74-76
 ###################################################
-## version 2011-12-01
+## version 2012-01-15
 options(continue = " ", digits = 3, width = 70)
 
 
 ###################################################
-### code chunk number 2: NMOFex.Rnw:95-97 (eval = FALSE)
+### code chunk number 2: NMOFex.Rnw:94-96 (eval = FALSE)
 ###################################################
 ## install.packages("NMOF") ### CRAN
 ## install.packages("NMOF", repos = "http://R-Forge.R-project.org")
 
 
 ###################################################
-### code chunk number 3: NMOFex.Rnw:100-102
+### code chunk number 3: NMOFex.Rnw:99-101
 ###################################################
 require("NMOF")
 set.seed(1112233344)
 
 
 ###################################################
-### code chunk number 4: NMOFex.Rnw:109-111 (eval = FALSE)
+### code chunk number 4: NMOFex.Rnw:108-110 (eval = FALSE)
 ###################################################
 ## whereToLook <- system.file("NMOFex/NMOFex.R", package = "NMOF")
 ## file.show(whereToLook, title = "NMOF examples")
 
 
 ###################################################
-### code chunk number 5: NMOFex.Rnw:134-149
+### code chunk number 5: NMOFex.Rnw:141-145
 ###################################################
-## using several cores
 testFun  <- function(x) {
     Sys.sleep(0.1) ## just wasting time :-)
     x[1L] + x[2L]^2
 }
-lower <- 1:3; upper <- 5; n <- 5L
+
+
+###################################################
+### code chunk number 6: NMOFex.Rnw:149-153
+###################################################
+lower <- c(1,3); upper <- 5; n <- 5L
 system.time(sol1 <- gridSearch(fun = testFun,
                                lower = lower, upper = upper,
                                n = n, printDetail = TRUE))
+
+
+###################################################
+### code chunk number 7: NMOFex.Rnw:157-159
+###################################################
+seq(from = 1, to = 5, length.out= n)  ## x_1
+seq(from = 3, to = 5, length.out= n)  ## x_2
+
+
+###################################################
+### code chunk number 8: NMOFex.Rnw:163-165
+###################################################
+sol1$minfun
+sol1$minlevels
+
+
+###################################################
+### code chunk number 9: NMOFex.Rnw:169-175
+###################################################
 system.time(sol2 <- gridSearch(fun = testFun,
                                lower = lower, upper = upper,
                                n = n, printDetail = FALSE,
                                method = "snow",  ### use 'snow' ...
-                               cl = 4L))         ### ... with 2 cores
+                               cl = 2L))         ### ... with 2 cores
 all.equal(sol1, sol2)
 
 
 ###################################################
-### code chunk number 6: NMOFex.Rnw:165-172
+### code chunk number 10: NMOFex.Rnw:191-198
 ###################################################
 ## create random data with vols between minVol and maxVol
 ## and pairwise correlation of 0.6
@@ -61,7 +84,7 @@ Sigma <- outer(Vols,Vols) * C
 
 
 ###################################################
-### code chunk number 7: NMOFex.Rnw:184-202
+### code chunk number 11: NMOFex.Rnw:210-228
 ###################################################
 ## objective function for LS/TA
 OF <- function(x, data) {
@@ -84,7 +107,7 @@ neighbour <- function(xc, data) {
 
 
 ###################################################
-### code chunk number 8: NMOFex.Rnw:209-215
+### code chunk number 12: NMOFex.Rnw:235-241
 ###################################################
 ## data
 data <- list(Sigma = Sigma,   ### cov-matrix
@@ -95,7 +118,7 @@ data <- list(Sigma = Sigma,   ### cov-matrix
 
 
 ###################################################
-### code chunk number 9: NMOFex.Rnw:219-224
+### code chunk number 13: NMOFex.Rnw:245-250
 ###################################################
 ## a random solution x0
 card0 <- sample(data$Kinf:data$Ksup, 1L, replace = FALSE)
@@ -105,7 +128,7 @@ x0[assets] <- TRUE
 
 
 ###################################################
-### code chunk number 10: NMOFex.Rnw:230-238
+### code chunk number 14: NMOFex.Rnw:256-264
 ###################################################
 ## *Local Search*
 algo <- list(x0 = x0, neighbour = neighbour, nS = 5000L,
@@ -118,7 +141,7 @@ system.time(solTA <- TAopt(OF, algo = algo, data = data))
 
 
 ###################################################
-### code chunk number 11: NMOFex.Rnw:320-328
+### code chunk number 15: NMOFex.Rnw:346-354
 ###################################################
 ## *Genetic Algorithm*
 OF2 <- function(x, data) {
@@ -131,7 +154,7 @@ OF2 <- function(x, data) {
 
 
 ###################################################
-### code chunk number 12: NMOFex.Rnw:334-337
+### code chunk number 16: NMOFex.Rnw:360-363
 ###################################################
 algo <- list(nB = na, nP = 100L, nG = 500L, prob = 0.002,
              printBar = FALSE, loopOF = FALSE)
@@ -139,7 +162,7 @@ system.time(solGA <- GAopt(OF = OF2, algo = algo, data = data))
 
 
 ###################################################
-### code chunk number 13: NMOFex.Rnw:340-345
+### code chunk number 17: NMOFex.Rnw:366-371
 ###################################################
 cat(
     "Local Search        ", format(sqrt(solLS$OFvalue), digits = 4), "\n",
@@ -149,7 +172,7 @@ cat(
 
 
 ###################################################
-### code chunk number 14: NMOFex.Rnw:369-377
+### code chunk number 18: NMOFex.Rnw:395-403
 ###################################################
 na <- 100L                                 ### number of assets
 ns <- 200L                                 ### number of scenarios
@@ -162,7 +185,7 @@ R <- R %*% diag(vols)
 
 
 ###################################################
-### code chunk number 15: NMOFex.Rnw:398-409
+### code chunk number 19: NMOFex.Rnw:424-435
 ###################################################
 data <- list(R = t(R),              ### scenarios
               theta = 0.005,         ### return threshold
@@ -178,7 +201,7 @@ data <- list(R = t(R),              ### scenarios
 
 
 ###################################################
-### code chunk number 16: NMOFex.Rnw:414-417
+### code chunk number 20: NMOFex.Rnw:440-443
 ###################################################
 x0 <- data$min + runif(data$na)*(data$max - data$min)
 x0[1:5]
@@ -186,7 +209,7 @@ sum(x0)
 
 
 ###################################################
-### code chunk number 17: NMOFex.Rnw:420-424
+### code chunk number 21: NMOFex.Rnw:448-452
 ###################################################
 temp <- R %*% x0             ### compute portfolio returns
 temp <- temp - data$theta
@@ -195,7 +218,7 @@ sum(temp)/ns                 ### semivariance
 
 
 ###################################################
-### code chunk number 18: NMOFex.Rnw:428-435
+### code chunk number 22: NMOFex.Rnw:457-464
 ###################################################
 OF <- function(x, data) {
     Rx <- crossprod(data$R, x)
@@ -207,14 +230,14 @@ OF <- function(x, data) {
 
 
 ###################################################
-### code chunk number 19: NMOFex.Rnw:443-445
+### code chunk number 23: NMOFex.Rnw:473-475
 ###################################################
 OF(x0, data)
 OF(cbind(x0, x0), data)
 
 
 ###################################################
-### code chunk number 20: NMOFex.Rnw:452-462
+### code chunk number 24: NMOFex.Rnw:482-492
 ###################################################
 repair <- function(x, data) {
     myFun <- function(x) x/sum(x)
@@ -229,7 +252,7 @@ repair2 <- function(x, data) {
 
 
 ###################################################
-### code chunk number 21: NMOFex.Rnw:466-471
+### code chunk number 25: NMOFex.Rnw:496-501
 ###################################################
 sum(x0)
 sum(repair(x0, data))
@@ -239,7 +262,7 @@ colSums(repair2(cbind(x0, x0), data))
 
 
 ###################################################
-### code chunk number 22: NMOFex.Rnw:474-485
+### code chunk number 26: NMOFex.Rnw:504-515
 ###################################################
 penalty <- function(x, data) {
     up <- data$max
@@ -255,7 +278,7 @@ penalty <- function(x, data) {
 
 
 ###################################################
-### code chunk number 23: NMOFex.Rnw:491-497
+### code chunk number 27: NMOFex.Rnw:521-527
 ###################################################
 x0[1L] <- 0.30
 penalty(x0, data)
@@ -266,7 +289,7 @@ penalty(cbind(x0, x0), data)
 
 
 ###################################################
-### code chunk number 24: NMOFex.Rnw:501-511
+### code chunk number 28: NMOFex.Rnw:531-541
 ###################################################
 algo <- list(nP = 100,        ### population size
              nG = 1000,       ### number of generations
@@ -281,7 +304,7 @@ algo <- list(nP = 100,        ### population size
 
 
 ###################################################
-### code chunk number 25: NMOFex.Rnw:516-523
+### code chunk number 29: NMOFex.Rnw:546-553
 ###################################################
 system.time(sol <- DEopt(OF = OF,algo = algo,data = data))
 16 * 100 * sqrt(sol$OFvalue)   ### solution quality
@@ -293,7 +316,7 @@ all(all.equal(sum(sol$xbest), 1),  ### budget constraint
 
 
 ###################################################
-### code chunk number 26: NMOFex.Rnw:532-539
+### code chunk number 30: NMOFex.Rnw:562-569
 ###################################################
 ## looping over the population
 algo$loopOF <- TRUE; algo$loopPen <- TRUE; algo$loopRepair <- TRUE
@@ -305,7 +328,7 @@ system.time(sol <- DEopt(OF = OF,algo = algo, data = data))
 
 
 ###################################################
-### code chunk number 27: NMOFex.Rnw:548-561
+### code chunk number 31: NMOFex.Rnw:579-592
 ###################################################
 algo$printDetail <- FALSE
 restartsDE <- restartOpt(fun = DEopt,      ### what function
@@ -323,7 +346,7 @@ weightsDE <- sapply(restartsDE, `[[`, "xbest")
 
 
 ###################################################
-### code chunk number 28: NMOFex.Rnw:564-569
+### code chunk number 32: NMOFex.Rnw:595-600
 ###################################################
 par(bty = "n", las = 1, mar = c(3, 4, 0, 0),
     ps = 8, tck = 0.001, mgp = c(3, 0.2, 0))
@@ -333,7 +356,7 @@ mtext("OF value",  side = 1, line = 1)
 
 
 ###################################################
-### code chunk number 29: NMOFex.Rnw:573-579
+### code chunk number 33: NMOFex.Rnw:604-610
 ###################################################
 par(bty = "n", las = 1, mar = c(3, 4, 0, 0),
     ps = 8, tck = 0.001, mgp = c(3, 0.2, 0))
@@ -344,7 +367,7 @@ mtext("weights", side = 2, line = 1.3, las = 1, padj = -5)
 
 
 ###################################################
-### code chunk number 30: NMOFex.Rnw:591-629
+### code chunk number 34: NMOFex.Rnw:622-660
 ###################################################
 algo$printDetail <- FALSE;  algo$nP <- 200L; restarts <- 20L
 nGs <- c(500L, 1000L, 2500L)
@@ -387,7 +410,7 @@ for (i in 1:3) lines(ecdf(res2[ ,i]), col = "blue", cex = 0.4)
 
 
 ###################################################
-### code chunk number 31: NMOFex.Rnw:638-645
+### code chunk number 35: NMOFex.Rnw:669-676
 ###################################################
 weightsDE <- sapply(restartsDE, `[[`, "xbest")
 par(bty = "n", las = 1, mar = c(3, 4, 0, 0),
@@ -399,7 +422,7 @@ mtext("weights", side = 2, line = 1.3, las = 1, padj = -5)
 
 
 ###################################################
-### code chunk number 32: NMOFex.Rnw:651-668
+### code chunk number 36: NMOFex.Rnw:682-699
 ###################################################
 algo <- list(nP = 100L,        ### population size
     nG = 1000L,                ### number of generations
@@ -421,7 +444,7 @@ all(all.equal(sum(sol$xbest),1),  ### budget constraint
 
 
 ###################################################
-### code chunk number 33: NMOFex.Rnw:674-706
+### code chunk number 37: NMOFex.Rnw:705-737
 ###################################################
 ## adjusting velocity
 changeV <- function(x, data) {
@@ -458,7 +481,7 @@ system.time(sol <- PSopt(OF = OF, algo = algo, data = data))
 
 
 ###################################################
-### code chunk number 34: NMOFex.Rnw:709-724
+### code chunk number 38: NMOFex.Rnw:740-755
 ###################################################
 algo$printDetail <- FALSE
 restartsPS <- restartOpt(fun = PSopt,
@@ -478,7 +501,7 @@ mtext("OF value",  side = 1, line = 1)
 
 
 ###################################################
-### code chunk number 35: NMOFex.Rnw:732-755
+### code chunk number 39: NMOFex.Rnw:763-786
 ###################################################
 data$R <- R  ## not transposed any more
 
@@ -506,7 +529,7 @@ OF <- function(x, data) {
 
 
 ###################################################
-### code chunk number 36: NMOFex.Rnw:758-771
+### code chunk number 40: NMOFex.Rnw:789-802
 ###################################################
 ## a random initial weights
 w0 <- runif(data$na); w0 <- w0/sum(w0)
@@ -524,7 +547,7 @@ system.time(sol2 <- TAopt(OF,algo,data))
 
 
 ###################################################
-### code chunk number 37: NMOFex.Rnw:775-795
+### code chunk number 41: NMOFex.Rnw:806-826
 ###################################################
 restartsTA <- restartOpt(fun = TAopt,
                          n = 20L,
@@ -549,7 +572,313 @@ lines(ecdf(OFvaluesTA), cex = 0.4)
 
 
 ###################################################
-### code chunk number 38: NMOFex.Rnw:817-846
+### code chunk number 42: NMOFex.Rnw:843-863
+###################################################
+cf1 <- c(rep(5.75,  8), 105.75); tm1 <- 0:8 + 0.5
+cf2 <- c(rep(4.25, 17), 104.25); tm2 <- 1:18
+cf3 <- c(3.5, 103.5); tm3 <- 0:1 + 0.5
+cf4 <- c(rep(3.00, 15), 103.00); tm4 <- 1:16
+cf5 <- c(rep(3.25, 11), 103.25); tm5 <- 0:11 + 0.5
+cf6 <- c(rep(5.75, 17), 105.75); tm6 <- 0:17 + 0.5
+cf7 <- c(rep(3.50, 14), 103.50); tm7 <- 1:15
+cf8 <- c(rep(5.00,  8), 105.00); tm8 <- 0:8 + 0.5
+cf9 <- 105; tm9 <- 1
+cf10 <- c(rep(3.00, 12), 103.00); tm10 <- 0:12 + 0.5
+cf11 <- c(rep(2.50,  7), 102.50); tm11 <- 1:8
+cf12 <- c(rep(4.00, 10), 104.00); tm12 <- 1:11
+cf13 <- c(rep(3.75, 18), 103.75); tm13 <- 0:18 + 0.5
+cf14 <- c(rep(4.00, 17), 104.00); tm14 <- 1:18
+cf15 <- c(rep(2.25,  8), 102.25); tm15 <- 0:8 + 0.5
+cf16 <- c(rep(4.00,  6), 104.00); tm16 <- 1:7
+cf17 <- c(rep(2.25, 12), 102.25); tm17 <- 1:13
+cf18 <- c(rep(4.50, 19), 104.50); tm18 <- 0:19 + 0.5
+cf19 <- c(rep(2.25,  7), 102.25); tm19 <- 1:8
+cf20 <- c(rep(3.00, 14), 103.00); tm20 <- 1:15
+
+
+###################################################
+### code chunk number 43: NMOFex.Rnw:869-884
+###################################################
+cfList <- list(cf1,cf2,cf3,cf4,cf5,cf6,cf7,cf8,cf9,cf10,
+               cf11,cf12,cf13,cf14,cf15,cf16,cf17,cf18,cf19,cf20)
+tmList <- list(tm1,tm2,tm3,tm4,tm5,tm6,tm7,tm8,tm9,tm10,
+               tm11,tm12,tm13,tm14,tm15,tm16,tm17,tm18,tm19,tm20)
+tm <- unlist(tmList, use.names = FALSE)
+tm <- sort(unique(tm))
+nR <- length(tm)
+nC <- length(cfList)
+
+cfMatrix <- array(0, dim = c(nR, nC))
+for(j in seq(nC))
+    cfMatrix[tm %in% tmList[[j]], j] <- cfList[[j]]
+rownames(cfMatrix) <- tm
+
+cfMatrix[1:10, 1:10]
+
+
+###################################################
+### code chunk number 44: NMOFex.Rnw:891-895
+###################################################
+betaTRUE <- c(5,-2,1,10,1,3)
+yM <- NSS(betaTRUE,tm)
+diFa <- 1 / ( (1 + yM/100)^tm )
+bM <- diFa %*% cfMatrix
+
+
+###################################################
+### code chunk number 45: NMOFex.Rnw:899-903
+###################################################
+data <- list(bM = bM, tm = tm, cfMatrix = cfMatrix, model = NSS,
+             ww = 1,
+            min = c( 0,-15,-30,-30,0  ,2.5),
+            max = c(15, 30, 30, 30,2.5,5  ))
+
+
+###################################################
+### code chunk number 46: NMOFex.Rnw:913-923
+###################################################
+OF2 <- function(param, data) {
+    tm <- data$tm
+    bM <- data$bM
+    cfMatrix <- data$cfMatrix
+    diFa  <- 1 / ((1 + data$model(param, tm)/100)^tm)
+    b <- diFa %*% cfMatrix
+    aux <- b - bM; aux <- max(abs(aux))
+    if (is.na(aux)) aux <- 1e10
+    aux
+}
+
+
+###################################################
+### code chunk number 47: NMOFex.Rnw:927-942
+###################################################
+penalty <- function(mP, data) {
+    minV <- data$min
+    maxV <- data$max
+    ww <- data$ww
+    ## if larger than maxV, element in A is positiv
+    A <- mP - as.vector(maxV)
+    A <- A + abs(A)
+    ## if smaller than minV, element in B is positiv
+    B <- as.vector(minV) - mP
+    B <- B + abs(B)
+    ## beta 1 + beta2 > 0
+    C <- ww*((mP[1L, ] + mP[2L, ]) - abs(mP[1L, ] + mP[2L, ]))
+    A <- ww * colSums(A + B) - C
+    A
+}
+
+
+###################################################
+### code chunk number 48: NMOFex.Rnw:947-963
+###################################################
+algo <- list(nP  = 200L,
+             nG  = 1000L,
+             F   = 0.50,
+             CR  = 0.99,
+             min = c( 0,-15,-30,-30,0  ,2.5),
+             max = c(15, 30, 30, 30,2.5,5  ),
+             pen = penalty,
+             repair = NULL,
+             loopOF = TRUE,
+             loopPen = FALSE,
+             loopRepair = FALSE,
+             printBar = FALSE,
+             printDetail = FALSE,
+             storeF = FALSE)
+
+sol <- DEopt(OF = OF2, algo = algo, data = data)
+
+
+###################################################
+### code chunk number 49: NMOFex.Rnw:969-971
+###################################################
+max( abs(data$model(sol$xbest, tm) - data$model(betaTRUE, tm)))
+sol$OFvalue
+
+
+###################################################
+### code chunk number 50: NMOFex.Rnw:975-992
+###################################################
+s0 <- algo$min + (algo$max - algo$min) * runif(length(algo$min))
+system.time(sol2 <- nlminb(s0,OF2,data = data,
+                                 lower = data$min,
+                                 upper = data$max,
+                               control = list(eval.max = 50000,
+                                              iter.max = 50000)))
+max(abs(data$model(sol2$par,tm) - data$model(betaTRUE,tm)))
+sol2$objective
+
+par(ps = 11, bty = "n", las = 1, tck = 0.01,
+    mgp = c(3, 0.2, 0), mar = c(4, 4, 1, 1))
+plot(tm, yM, xlab = "maturities in years", ylab = "yields in %")
+lines(tm,data$model(sol$xbest,tm), col = "blue")
+lines(tm,data$model(sol2$par,tm), col = "darkgreen", lty = 2)
+legend(x = "bottom", legend = c("true yields", "DE", "nlminb"),
+       col = c("black", "blue", "darkgreen"),
+       pch = c(1, NA, NA), lty = c(0, 1, 2))
+
+
+###################################################
+### code chunk number 51: NMOFex.Rnw:996-999
+###################################################
+diFa <- 1 / ((1 + NSS(sol$xbest,tm)/100)^tm)
+b <- diFa %*% cfMatrix
+b - bM
+
+
+###################################################
+### code chunk number 52: NMOFex.Rnw:1003-1007
+###################################################
+par(ps = 11, bty = "n", las = 1, tck = 0.01,
+    mgp = c(3, 0.2, 0), mar = c(4, 4, 1, 1))
+plot(tm, NSS(sol$xbest,tm) - NSS(betaTRUE,tm),
+     xlab = "maturities in years", ylab = "yield error in %")
+
+
+###################################################
+### code chunk number 53: NMOFex.Rnw:1013-1017
+###################################################
+par(ps = 11, bty = "n", las = 1, tck = 0.01,
+    mgp = c(3, 0.2, 0), mar = c(4, 4, 1, 1))
+plot(as.numeric(unlist(lapply(tmList, max))), as.vector(b - bM),
+     xlab = "maturities in years", ylab = "price error in %")
+
+
+###################################################
+### code chunk number 54: NMOFex.Rnw:1028-1047
+###################################################
+fy <- function(ytm, cf, tm)
+    sum( cf / ( (1 + ytm)^tm ) )
+compYield <- function(cf, tm, guess = NULL) {
+    logik <- cf != 0
+    cf <- cf[logik]
+    tm <- tm[logik]
+    if (is.null(guess)) {ytm <- 0.05} else {ytm <- guess}
+    h <- 1e-8;	dF <- 1; ci <- 0
+    while (abs(dF) > 1e-5) {
+        ci <- ci + 1; if (ci > 5) break
+        FF  <-  fy(ytm, cf, tm)
+        dFF <- (fy(ytm + h, cf, tm) - FF) / h
+        dF <- FF / dFF
+        ytm <- ytm - dF
+    }
+    if (ytm < 0)
+        ytm <- 0.99
+    ytm
+}
+
+
+###################################################
+### code chunk number 55: NMOFex.Rnw:1051-1077
+###################################################
+OF3 <- function(param, data) {
+    tm <- data$tm
+    rM <- data$rM
+    cfMatrix<- data$cfMatrix
+    nB <- dim(cfMatrix)[2L]
+    zrates <- data$model(param,tm); aux <- 1e10
+    if ( all(zrates > 0,
+             !is.na(zrates))
+        ) {
+        diFa <- 1 / ((1 + zrates/100)^tm)
+        b <- diFa %*% cfMatrix
+        r <- numeric(nB)
+        if ( all(!is.na(b),
+                 diFa < 1,
+                 diFa > 0,
+                 b > 1)
+            ) {
+            for (bb in 1:nB) {
+                r[bb] <- compYield(c(-b[bb], cfMatrix[ ,bb]), c(0,tm))
+            }
+            aux <- abs(r - rM)
+            aux <- sum(aux)
+        }
+    }
+    aux
+}
+
+
+###################################################
+### code chunk number 56: NMOFex.Rnw:1086-1091
+###################################################
+betaTRUE <- c(5,-2,1,10,1,3)
+yM <- NSS(betaTRUE, tm)
+diFa <- 1 / ( (1 + yM/100)^tm )
+bM <- diFa %*% cfMatrix
+rM <- apply(rbind(-bM, cfMatrix), 2, compYield, c(0, tm))
+
+
+###################################################
+### code chunk number 57: NMOFex.Rnw:1095-1115
+###################################################
+data <- list(rM = rM, tm = tm,
+             cfMatrix = cfMatrix,
+             model = NSS,
+             min = c( 0,-15,-30,-30,0  ,2.5),
+             max = c(15, 30, 30, 30,2.5,5  ),
+             ww = 0.1,
+             fy = fy)
+algo <- list(nP = 100L,
+             nG = 1000L,
+             F  = 0.50,
+             CR = 0.99,
+             min = c( 0,-15,-30,-30,0  ,2.5),
+             max = c(15, 30, 30, 30,2.5,5  ),
+             pen = penalty,
+             repair = NULL,
+             loopOF = TRUE,
+             loopPen = FALSE,
+             loopRepair = FALSE,
+             printBar = FALSE,
+             printDetail = FALSE)
+
+
+###################################################
+### code chunk number 58: NMOFex.Rnw:1118-1121
+###################################################
+sol <- DEopt(OF = OF3, algo = algo, data = data)
+max(abs(data$model(sol$xbest,tm) - data$model(betaTRUE,tm)))
+sol$OFvalue
+
+
+###################################################
+### code chunk number 59: NMOFex.Rnw:1125-1133
+###################################################
+s0 <- algo$min + (algo$max - algo$min) * runif(length(algo$min))
+sol2 <- nlminb(s0, OF3, data = data,
+                                   lower = algo$min,
+                                   upper = algo$max,
+                                 control = list(eval.max = 50000L,
+                                                iter.max = 50000L))
+max(abs(data$model(sol2$par,tm) - data$model(betaTRUE,tm)))
+sol2$objective
+
+
+###################################################
+### code chunk number 60: NMOFex.Rnw:1136-1145
+###################################################
+par(ps = 11, bty = "n", las = 1, tck = 0.01,
+    mgp = c(3, 0.2, 0), mar = c(4, 4, 1, 1))
+plot(tm, yM, xlab = "maturities in years", ylab = "yields in %")
+lines(tm,data$model(sol$xbest,tm), col = "blue")
+lines(tm,data$model(sol2$par,tm), col = "darkgreen", lty = 2)
+
+legend(x = "bottom", legend = c("true yields","DE","nlminb"),
+       col = c("black", "blue", "darkgreen"),
+       pch = c(1, NA, NA), lty = c(0,1,2))
+
+
+###################################################
+### code chunk number 61: NMOFex.Rnw:1149-1151
+###################################################
+betaTRUE
+round(sol$xbest,3)
+
+
+###################################################
+### code chunk number 62: NMOFex.Rnw:1180-1209
 ###################################################
 randomData <- function(
     p = 200L,      ### number of available regressors
@@ -583,7 +912,7 @@ data <- list(X = rD$X,
 
 
 ###################################################
-### code chunk number 39: NMOFex.Rnw:852-856
+### code chunk number 63: NMOFex.Rnw:1215-1219
 ###################################################
 x0 <- logical(data$p)
 temp <- sample.int(data$maxk, 1L)
@@ -592,7 +921,7 @@ x0[temp] <- TRUE
 
 
 ###################################################
-### code chunk number 40: NMOFex.Rnw:865-876
+### code chunk number 64: NMOFex.Rnw:1228-1239
 ###################################################
 require(rbenchmark)
 benchmark(lm(data$y ~ -1 + data$X[ ,x0]),
@@ -608,7 +937,7 @@ all.equal(as.numeric(coef(ignore1)), as.numeric(ignore2))
 
 
 ###################################################
-### code chunk number 41: NMOFex.Rnw:885-891
+### code chunk number 65: NMOFex.Rnw:1248-1254
 ###################################################
 OF <- function(x, data) {
     q <- qr(data$X[ ,x])
@@ -619,7 +948,7 @@ OF(x0, data)
 
 
 ###################################################
-### code chunk number 42: NMOFex.Rnw:896-905
+### code chunk number 66: NMOFex.Rnw:1259-1268
 ###################################################
 neighbour <- function(xc, data) {
     xn <- xc
@@ -633,7 +962,7 @@ neighbour(x0, data)[1:10]
 
 
 ###################################################
-### code chunk number 43: NMOFex.Rnw:910-918
+### code chunk number 67: NMOFex.Rnw:1273-1281
 ###################################################
 algo <- list(
     nT = 10L,    ### number of thresholds
@@ -646,7 +975,7 @@ system.time(sol1 <- TAopt(OF, algo = algo, data = data))
 
 
 ###################################################
-### code chunk number 44: NMOFex.Rnw:923-926
+### code chunk number 68: NMOFex.Rnw:1286-1289
 ###################################################
 sol1$OFvalue
 which(sol1$xbest)  ### the selected regressors
@@ -654,7 +983,7 @@ rD$K               ### the true regressors
 
 
 ###################################################
-### code chunk number 45: NMOFex.Rnw:933-937
+### code chunk number 69: NMOFex.Rnw:1296-1300
 ###################################################
 xtrue <- logical(data$p)
 xtrue[rD$K] <- TRUE
@@ -663,7 +992,7 @@ OF(xtrue, data)
 
 
 ###################################################
-### code chunk number 46: NMOFex.Rnw:944-953
+### code chunk number 70: NMOFex.Rnw:1307-1316
 ###################################################
 restarts <- 50L
 algo$printDetail <- FALSE
@@ -677,7 +1006,7 @@ plot(ecdf(sapply(res, `[[`, "OFvalue")),  ### extract solution quality
 
 
 ###################################################
-### code chunk number 47: NMOFex.Rnw:958-966
+### code chunk number 71: NMOFex.Rnw:1321-1329
 ###################################################
 xbestAll <- sapply(res, `[[`, "xbest")    ### extract all solutions
 inclReg  <- which(rowSums(xbestAll) > 0L) ### get included regressors
@@ -690,7 +1019,7 @@ data.frame(
 
 
 ###################################################
-### code chunk number 48: NMOFex.Rnw:997-1004
+### code chunk number 72: NMOFex.Rnw:1360-1367
 ###################################################
 size <- 20L
 x <- logical(size)
@@ -702,17 +1031,21 @@ Data$size <- size
 
 
 ###################################################
-### code chunk number 49: NMOFex.Rnw:1008-1023
+### code chunk number 73: NMOFex.Rnw:1371-1379
 ###################################################
 compareLogicals <- function(x, y, ...) {
     argsL <- list(...)
     if (!("sep" %in% names(argsL))) argsL$sep <- ""
     do.call("cat",
-            c(list(as.integer(x), "\n", as.integer(y), "\n",
+            c(list("\n",as.integer(x), "\n", as.integer(y), "\n",
                    ifelse(x == y, " ", "^"), "\n"), argsL)
             )
         }
 
+
+###################################################
+### code chunk number 74: NMOFex.Rnw:1383-1389
+###################################################
 ## there should be no difference
 compareLogicals(x, x)
 
@@ -722,9 +1055,9 @@ compareLogicals(x, z)
 
 
 ###################################################
-### code chunk number 50: NMOFex.Rnw:1027-1034
+### code chunk number 75: NMOFex.Rnw:1395-1402
 ###################################################
-Data$n <- 5  ### how many elements to change
+Data$n <- 5L  ## how many elements to change
 neighbour <- function(x, Data) {
     ii <- sample.int(Data$size, Data$n)
     x[ii] <- !x[ii]
@@ -734,11 +1067,10 @@ compareLogicals(x, neighbour(x, Data))
 
 
 ###################################################
-### code chunk number 51: NMOFex.Rnw:1038-1050
+### code chunk number 76: NMOFex.Rnw:1411-1422
 ###################################################
-## requirement: start with a solution with at least
-## one TRUE and one FALSE
 neighbour <- function(x, Data) {
+    ## required: x must have at least one TRUE and one FALSE
     Ts <- which(x)
     Fs <- which(!x)
     lenTs <- length(Ts)
@@ -751,7 +1083,7 @@ compareLogicals(x, neighbour(x, Data))
 
 
 ###################################################
-### code chunk number 52: NMOFex.Rnw:1093-1107
+### code chunk number 77: NMOFex.Rnw:1434-1448
 ###################################################
 ## match a binary (logical) string y
 size <- 20L             ## the length of the string
@@ -770,7 +1102,7 @@ OF(sol$xbest, y)
 
 
 ###################################################
-### code chunk number 53: NMOFex.Rnw:1112-1125
+### code chunk number 78: NMOFex.Rnw:1453-1466
 ###################################################
 OF <- function(x, y) {
     Sys.sleep(0.01)
@@ -788,7 +1120,7 @@ OF(sol$xbest, y)
 
 
 ###################################################
-### code chunk number 54: NMOFex.Rnw:1165-1172
+### code chunk number 79: NMOFex.Rnw:1506-1513
 ###################################################
 OF <- tfTrefethen
 n <- 100L
@@ -800,7 +1132,7 @@ for (i in seq_len(n))
 
 
 ###################################################
-### code chunk number 55: NMOFex.Rnw:1179-1185
+### code chunk number 80: NMOFex.Rnw:1520-1526
 ###################################################
 par(bty = "n", las = 1, mar = c(3,4,0,0),
     ps = 8, tck = 0.001, mgp = c(3, 0.2, 0))
@@ -811,7 +1143,7 @@ abline(v = -0.02440308, h = 0.21061243, col = grey(0.6))
 
 
 ###################################################
-### code chunk number 56: NMOFex.Rnw:1190-1196
+### code chunk number 81: NMOFex.Rnw:1531-1537
 ###################################################
 algo <- list(nP = 50L, nG = 300L,
              F = 0.6, CR = 0.9,
@@ -822,7 +1154,7 @@ sol <- DEopt(OF = OF, algo = algo)
 
 
 ###################################################
-### code chunk number 57: NMOFex.Rnw:1199-1205
+### code chunk number 82: NMOFex.Rnw:1540-1546
 ###################################################
 names(sol)
 sd(sol$popF)
@@ -833,7 +1165,7 @@ xlist <- sol$xlist[[1L]]
 
 
 ###################################################
-### code chunk number 58: NMOFex.Rnw:1213-1228
+### code chunk number 83: NMOFex.Rnw:1554-1569
 ###################################################
 ## show solution 1 (column 1) in population over time
 xlist[[  1L]][ ,1L]  ### at the end of generation 1
@@ -853,7 +1185,7 @@ res[ ,300L]
 
 
 ###################################################
-### code chunk number 59: NMOFex.Rnw:1232-1246
+### code chunk number 84: NMOFex.Rnw:1573-1587
 ###################################################
 ## show parameter 2 (row 2) in population over time
 xlist[[  1L]][2L, ]  ### at the end of generation 1
@@ -872,7 +1204,7 @@ res[ ,300L]
 
 
 ###################################################
-### code chunk number 60: NMOFex.Rnw:1251-1260 (eval = FALSE)
+### code chunk number 85: NMOFex.Rnw:1592-1601 (eval = FALSE)
 ###################################################
 ## ## transposing xlist[[i]] gives a two-column matrix -- see ?points
 ## ## initial solutions
@@ -886,7 +1218,7 @@ res[ ,300L]
 
 
 ###################################################
-### code chunk number 61: NMOFex.Rnw:1263-1291
+### code chunk number 86: NMOFex.Rnw:1604-1632
 ###################################################
 setEPS()
 postscript(file = "figures/c1.eps", width = 2, height = 2)
@@ -919,7 +1251,7 @@ sep = "")
 
 
 ###################################################
-### code chunk number 62: NMOFex.Rnw:1302-1317
+### code chunk number 87: NMOFex.Rnw:1643-1658
 ###################################################
 OF <- function(par, Data) {
     ## compute model yields
@@ -939,7 +1271,7 @@ OF <- function(par, Data) {
 
 
 ###################################################
-### code chunk number 63: NMOFex.Rnw:1322-1339
+### code chunk number 88: NMOFex.Rnw:1663-1680
 ###################################################
 algo <- list(nP = 200L, nG = 100L,
              F = 0.50, CR = 0.99,
@@ -961,7 +1293,7 @@ p1 <- sapply(P, `[`, 1L, TRUE)
 
 
 ###################################################
-### code chunk number 64: NMOFex.Rnw:1346-1355
+### code chunk number 89: NMOFex.Rnw:1687-1696
 ###################################################
 par(bty = "n", las = 1, mar = c(4,4,0,0),
     ps = 8, tck = 0.001, mgp = c(3, 0.2, 0))
@@ -975,7 +1307,7 @@ mtext("parameter\nvalue", 2, line = 1)
 
 
 ###################################################
-### code chunk number 65: NMOFex.Rnw:1362-1397
+### code chunk number 90: NMOFex.Rnw:1703-1738
 ###################################################
 OF2 <- function(par, Data) {
     ## compute model yields
@@ -1015,7 +1347,7 @@ mtext("parameter\nvalue", 2, line = 1)
 
 
 ###################################################
-### code chunk number 66: NMOFex.Rnw:1409-1419
+### code chunk number 91: NMOFex.Rnw:1750-1760
 ###################################################
 testFun <- function(x) {
     Sys.sleep(0.1) ## wasting time :-)
@@ -1030,13 +1362,13 @@ all.equal(sol1, sol2)
 
 
 ###################################################
-### code chunk number 67: NMOFex.Rnw:1450-1451
+### code chunk number 92: NMOFex.Rnw:1791-1792
 ###################################################
 cfBSM
 
 
 ###################################################
-### code chunk number 68: NMOFex.Rnw:1455-1474
+### code chunk number 93: NMOFex.Rnw:1796-1815
 ###################################################
 S <- 100    ## spot
 X <- 100    ## strike
@@ -1060,7 +1392,7 @@ callCF(cf = cfBSM, S = S, X = X, tau = tau, r = r, q = q,
 
 
 ###################################################
-### code chunk number 69: NMOFex.Rnw:1499-1500
+### code chunk number 94: NMOFex.Rnw:1840-1841
 ###################################################
 toLatex(sessionInfo())
 
